CreateCoreDefinitionVersionResponse class

Constructors

CreateCoreDefinitionVersionResponse({String? arn, String? creationTimestamp, String? id, String? version})
CreateCoreDefinitionVersionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The ARN of the version.
final
creationTimestamp → String?
The time, in milliseconds since the epoch, when the version was created.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The ID of the parent definition that the version is associated with.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String?
The ID of the version.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited